cointrader package
==================

Subpackages
-----------

.. toctree::

    cointrader.exchanges
    cointrader.strategies

Submodules
----------

cointrader.chart module
-----------------------

.. automodule:: cointrader.chart
    :members:
    :undoc-members:
    :show-inheritance:

cointrader.cli module
---------------------

.. automodule:: cointrader.cli
    :members:
    :undoc-members:
    :show-inheritance:

cointrader.cointrader module
----------------------------

.. automodule:: cointrader.cointrader
    :members:
    :undoc-members:
    :show-inheritance:

cointrader.config module
------------------------

.. automodule:: cointrader.config
    :members:
    :undoc-members:
    :show-inheritance:

cointrader.exchange module
--------------------------

.. automodule:: cointrader.exchange
    :members:
    :undoc-members:
    :show-inheritance:

cointrader.strategy module
--------------------------

.. automodule:: cointrader.strategy
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cointrader
    :members:
    :undoc-members:
    :show-inheritance:
